@@ -1,10 +1,8 @@
-#include <Rcpp.h>
+#include "z-derivs.h"
 #include "util.h"
 
-// Sum (from j=0 to j=max) of j*lambda^j/((j!)^nu)
-// [[Rcpp::export]]
 Rcpp::NumericVector z_prodj(const Rcpp::NumericVector& lambda,
-	const Rcpp::NumericVector& nu, unsigned int max = 100)
+	const Rcpp::NumericVector& nu, unsigned int max)
 {
 	unsigned int n = lambda.size();
 	if (n != nu.size()) {
@@ -21,10 +19,8 @@ Rcpp::NumericVector z_prodj(const Rcpp::NumericVector& lambda,
 	return res;
 }
 
-// Sum (from j=0 to j=max) of j^2*lambda^j/((j!)^nu)
-// [[Rcpp::export]]
 Rcpp::NumericVector z_prodj2(const Rcpp::NumericVector& lambda,
-	const Rcpp::NumericVector& nu, unsigned int max = 100)
+	const Rcpp::NumericVector& nu, unsigned int max)
 {
 	unsigned int n = lambda.size();
 	if (n != nu.size()) {
@@ -41,10 +37,8 @@ Rcpp::NumericVector z_prodj2(const Rcpp::NumericVector& lambda,
 	return res;
 }
 
-// Sum (from j=0 to j=max) of jlog(j!)*lambda^j/((j!)^nu)
-// [[Rcpp::export]]
 Rcpp::NumericVector z_prodjlogj(const Rcpp::NumericVector& lambda,
-	const Rcpp::NumericVector& nu, unsigned int max = 100)
+	const Rcpp::NumericVector& nu, unsigned int max)
 {
 	unsigned int n = lambda.size();
 	if (n != nu.size()) {
@@ -61,10 +55,8 @@ Rcpp::NumericVector z_prodjlogj(const Rcpp::NumericVector& lambda,
 	return res;
 }
 
-// Sum (from j=0 to j=max) of log(j!)*lambda^j/((j!)^nu)
-// [[Rcpp::export]]
 Rcpp::NumericVector z_prodlogj(const Rcpp::NumericVector& lambda,
-	const Rcpp::NumericVector& nu, unsigned int max = 100)
+	const Rcpp::NumericVector& nu, unsigned int max)
 {
 	unsigned int n = lambda.size();
 	if (n != nu.size()) {
@@ -81,10 +73,8 @@ Rcpp::NumericVector z_prodlogj(const Rcpp::NumericVector& lambda,
 	return res;
 }
 
-// Sum (from j=0 to j=max) of (log(j!))^2 * lambda^j/((j!)^nu)
-// [[Rcpp::export]]
 Rcpp::NumericVector z_prodlogj2(const Rcpp::NumericVector& lambda,
-	const Rcpp::NumericVector& nu, unsigned int max = 100)
+	const Rcpp::NumericVector& nu, unsigned int max)
 {
 	unsigned int n = lambda.size();
 	if (n != nu.size()) {
